@@ -180,6 +180,7 @@ class Manager(object):
         SubElement(IdDoc, "FchEmis").text = str(self.comprobante.date)
         if self.comprobante.include_tax: SubElement(IdDoc, "MntBruto").text = '1'
         if self.comprobante.payment_method: SubElement(IdDoc, "FmaPago").text = str(self.comprobante.payment_method)
+        if hasattr(self.comprobante, 'own_collection'): SubElement(IdDoc,"IndCobPropia").text = '1'
         if self.comprobante.date_due: SubElement(IdDoc, "FchVenc").text = str(self.comprobante.date_due)
 
         if self.comprobante.incoterm_code: SubElement(IdDoc, "ClauVenta").text = str(self.comprobante.incoterm_code)
@@ -530,7 +531,7 @@ class Manager(object):
 
     def get_mnt_base(self, indicator):
         total = sum([line.amount - line.tax if line.include_tax else line.amount for line in self.comprobante.invoice_lines if str(line.invoice_indicator) == str(indicator)])
-        total_discount = sum([line_discount.amount for line_discount in self.comprobante.invoice_discount_lines if
+        total_discount = sum([line_discount.amount - line_discount.tax if line_discount.include_tax else line_discount.amount for line_discount in self.comprobante.invoice_discount_lines if
                               str(line_discount.invoice_indicator) == str(indicator)]) if\
             hasattr(self.comprobante,'invoice_discount_lines') else 0
         return total - total_discount if total else 0
@@ -563,15 +564,15 @@ class Manager(object):
         return self.get_tax(INVOICE_INDICATOR.get('taxable_basic'))
 
     def get_total_amount(self):
-        total_basic = self.get_mnt_iva_tasa_basic() + self.get_mnt_base_iva_tasa_basic()
-        total_min = self.get_mnt_iva_tasa_min() + self.get_mnt_base_iva_tasa_min()
-        total_no_taxable = self.get_mnt_non_taxable()
-        total_exempt = self.get_mnt_exempt()
-        total_exportation = self.get_mnt_exportation()
+        total_basic = round(self.get_mnt_iva_tasa_basic(),2) + round(self.get_mnt_base_iva_tasa_basic(),2)
+        total_min = round(self.get_mnt_iva_tasa_min(),2) + round(self.get_mnt_base_iva_tasa_min(),2)
+        total_no_taxable = round(self.get_mnt_non_taxable(),2)
+        total_exempt = round(self.get_mnt_exempt(),2)
+        total_exportation = round(self.get_mnt_exportation(),2)
         return total_basic + total_min + total_no_taxable + total_exempt + total_exportation
 
     def get_total_to_pay(self):
-        return self.get_total_amount() + self.get_mnt_non_invoiceable() + self.get_mnt_negative_non_invoiceable()
+        return self.get_total_amount() + round(self.get_mnt_non_invoiceable(),2) + round(self.get_mnt_negative_non_invoiceable(),2)
 
     def get_total_retention(self):
         return sum([ret.get_amount() for ret in self.comprobante.retentions])
