@@ -129,7 +129,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
     
     # Ejemplo para e-Factura con cobranza
     def test_eFact_cfe_invoice_receipt(self):
@@ -173,7 +173,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # Ejemplo para e-Factura con impuesto de exportacion
     def test_eFact_cfe_invoice_with_tax_exportation(self):
@@ -214,7 +214,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # X.X.X.X Ejemplo para e-Factura exportacion zona franca ( no se encuentra en manual)
     def test_eFact_zona_franca_cfe_invoice(self):
@@ -248,7 +248,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # Ejemplo para e-Factura con descuento
     def test_eFact_cfe_invoice_with_discount(self):
@@ -284,7 +284,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.7.1 Ejemplo para e-Boleta de entrada
     def test_eBoleta_cfe_invoice(self):
@@ -319,7 +319,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.1.1 Ejemplo para e-Ticket con pasaporte
     def test_eTck_cfe_invoice_with_passport(self):
@@ -357,7 +357,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.1.1 Ejemplo para e-Ticket
     def test_eTck_cfe_invoice(self):
@@ -396,7 +396,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # Idem 6.2.1.1 Ejemplo para e-Ticket con Exento
     def test_eTck_cfe_invoice_exempt(self):
@@ -429,7 +429,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.1.2 Ejemplo para e-Ticket venta por cuenta ajena
     def test_eTck_cfe_invoice_alien(self):
@@ -468,7 +468,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.1.3 Ejemplo para nota de credito de e-Ticket
     def test_eTck_cfe_refund(self):
@@ -515,7 +515,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.3.1 Ejemplo para e-Factura exportacion con documento uruguayo
     def test_eFact_cfe_invoice_exportation_for_uyu_partner(self):
@@ -554,7 +554,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.3.1 Ejemplo para e-Factura exportacion
     def test_eFact_cfe_invoice_exportation(self):
@@ -593,7 +593,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.4.1 Ejemplo para un e-Remito
     def test_eRem(self):
@@ -622,7 +622,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.4.2 Ejemplo para una correcion de e-Remito
     def test_eRem_correccion(self):
@@ -662,7 +662,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.5.1 Ejemplo para un e-Remito exportacion
     def test_eRem_exportacion(self):
@@ -698,7 +698,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # Ejemplo para un e-Resguardo con referencia
     def test_eRes_with_reference(self):
@@ -764,7 +764,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.6.1 Ejemplo para un e-Resguardo
     def test_eRes(self):
@@ -814,7 +814,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # e-Resguardo con referencias
     def test_eRes_with_references(self):
@@ -858,7 +858,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # 6.2.6.2 Ejemplo para una correccion de e-Resguardo
     def test_eRes_refund(self):
@@ -903,7 +903,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg')
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
 
     # Ejemplo con contingencia - CFC
 
@@ -949,7 +949,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.7.1 Ejemplo para e-Boleta de entrada
     def test_eBoleta_cfc_invoice(self):
@@ -987,7 +987,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.1.1 Ejemplo para e-Ticket
     def test_eTck_cfc_invoice(self):
@@ -1029,7 +1029,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.1.2 Ejemplo para e-Ticket venta por cuenta ajena
     def test_eTck_cfc_invoice_alien(self):
@@ -1072,7 +1072,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.1.3 Ejemplo para nota de credito de e-Ticket
     def test_eTck_cfc_refund(self):
@@ -1122,7 +1122,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.3.1 Ejemplo para e-Factura exportacion
     def test_eFact_cfc_invoice_exportation(self):
@@ -1164,7 +1164,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.4.1 Ejemplo para un e-Remito
     def test_eRem_cfc(self):
@@ -1196,7 +1196,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.4.2 Ejemplo para una correcion de e-Remito
     def test_eRem_correccion_cfc(self):
@@ -1239,7 +1239,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.5.1 Ejemplo para un e-Remito exportacion
     def test_eRem_exportacion_cfc(self):
@@ -1278,7 +1278,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.6.1 Ejemplo para un e-Resguardo
     def test_eRes_cfc(self):
@@ -1331,7 +1331,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # 6.2.6.2 Ejemplo para una correccion de e-Resguardo
     def test_eRes_refund_cfc(self):
@@ -1379,7 +1379,7 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
-        assert not msg.get('responseMsg') or msg.get('responseMsg') == MESSAGE_ERROR_CFC
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage) or msg.get('responseMsg') == MESSAGE_ERROR_CFC
 
     # Consulta de estado para un 6.2.2.1 Ejemplo para e-Factura
     def test_eFact_cfe_invoice_state(self):
@@ -1420,6 +1420,8 @@ class TestUruware(unittest.TestCase):
 
         msg = Manager(self.emisor, comprobante, self.connection_data).send_document()
 
+        assert not (msg.get('responseMsg') or msg.get('responseBody').ErrorMessage)
+
         comprobante.cfe_serial = msg.get('responseBody').Resp.Serie
         comprobante.cfe_number = msg.get('responseBody').Resp.NumeroCfe
 
